# Provide Name and Description for package

[![Build Status](https://readthedocs.org/projects/unv_web/badge/?version=latest&style=flat)](https://readthedocs.org/projects/unv_web)
[![Docs Build Status](https://travis-ci.org/c137digital/unv_web.svg?branch=master)](https://travis-ci.org/c137digital/unv_web)
[![Maintainability](https://api.codeclimate.com/v1/badges/0ab28a851d216b5ed883/maintainability)](https://codeclimate.com/github/c137digital/unv_web/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/0ab28a851d216b5ed883/test_coverage)](https://codeclimate.com/github/c137digital/unv_web/test_coverage)
[![Requirements Status](https://requires.io/github/c137digital/unv_web/requirements.svg?branch=master)](https://requires.io/github/c137digital/unv_web/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/unv_web.svg)](https://pypi.python.org/pypi/unv_web/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/unv_web.svg)](https://pypi.python.org/pypi/unv_web/)
[![PyPI license](https://img.shields.io/pypi/l/unv_web.svg)](https://pypi.python.org/pypi/unv_web/)
[![PyPI version fury.io](https://badge.fury.io/py/unv.web.svg)](https://pypi.python.org/pypi/unv_web/)
[![PyPI download month](https://img.shields.io/pypi/dm/unv_web.svg)](https://pypi.python.org/pypi/unv_web/)

## What you need to change

- package name to whatever you want
- setup.py
  - name
  - description
  - author (git)
  - email (git)
  - install_requires + requirements.txt
  - LICENSE
